==> open-cluster-management-cluster-model-6.3.1-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1/ManagedClusterSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ManagedClusterSpecFluent<A extends ManagedClusterSpecFluent<A>> extends Fluent<A>{
  public Boolean getHubAcceptsClient();
  public A withHubAcceptsClient(Boolean hubAcceptsClient);
  public Boolean hasHubAcceptsClient();
  public Integer getLeaseDurationSeconds();
  public A withLeaseDurationSeconds(Integer leaseDurationSeconds);
  public Boolean hasLeaseDurationSeconds();
  public A addToManagedClusterClientConfigs(Integer index,ClientConfig item);
  public A setToManagedClusterClientConfigs(Integer index,ClientConfig item);
  public A addToManagedClusterClientConfigs(io.fabric8.openclustermanagement.api.model.cluster.v1.ClientConfig... items);
  public A addAllToManagedClusterClientConfigs(Collection<ClientConfig> items);
  public A removeFromManagedClusterClientConfigs(io.fabric8.openclustermanagement.api.model.cluster.v1.ClientConfig... items);
  public A removeAllFromManagedClusterClientConfigs(Collection<ClientConfig> items);
  public A removeMatchingFromManagedClusterClientConfigs(Predicate<ClientConfigBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildManagedClusterClientConfigs instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ClientConfig> getManagedClusterClientConfigs();
  public List<ClientConfig> buildManagedClusterClientConfigs();
  public ClientConfig buildManagedClusterClientConfig(Integer index);
  public ClientConfig buildFirstManagedClusterClientConfig();
  public ClientConfig buildLastManagedClusterClientConfig();
  public ClientConfig buildMatchingManagedClusterClientConfig(Predicate<ClientConfigBuilder> predicate);
  public Boolean hasMatchingManagedClusterClientConfig(Predicate<ClientConfigBuilder> predicate);
  public A withManagedClusterClientConfigs(List<ClientConfig> managedClusterClientConfigs);
  public A withManagedClusterClientConfigs(io.fabric8.openclustermanagement.api.model.cluster.v1.ClientConfig... managedClusterClientConfigs);
  public Boolean hasManagedClusterClientConfigs();
  public A addNewManagedClusterClientConfig(String caBundle,String url);
  public ManagedClusterSpecFluent.ManagedClusterClientConfigsNested<A> addNewManagedClusterClientConfig();
  public ManagedClusterSpecFluent.ManagedClusterClientConfigsNested<A> addNewManagedClusterClientConfigLike(ClientConfig item);
  public ManagedClusterSpecFluent.ManagedClusterClientConfigsNested<A> setNewManagedClusterClientConfigLike(Integer index,ClientConfig item);
  public ManagedClusterSpecFluent.ManagedClusterClientConfigsNested<A> editManagedClusterClientConfig(Integer index);
  public ManagedClusterSpecFluent.ManagedClusterClientConfigsNested<A> editFirstManagedClusterClientConfig();
  public ManagedClusterSpecFluent.ManagedClusterClientConfigsNested<A> editLastManagedClusterClientConfig();
  public ManagedClusterSpecFluent.ManagedClusterClientConfigsNested<A> editMatchingManagedClusterClientConfig(Predicate<ClientConfigBuilder> predicate);
  public A withHubAcceptsClient();
  public interface ManagedClusterClientConfigsNested<N> extends Nested<N>,ClientConfigFluent<ManagedClusterSpecFluent.ManagedClusterClientConfigsNested<N>>{
    public N and();
    public N endManagedClusterClientConfig();
    
  }
  
}

==> open-cluster-management-cluster-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1/ManagedClusterSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ManagedClusterSpecFluent<A extends ManagedClusterSpecFluent<A>> extends Fluent<A>{
  public Boolean getHubAcceptsClient();
  public A withHubAcceptsClient(Boolean hubAcceptsClient);
  public Boolean hasHubAcceptsClient();
  public Integer getLeaseDurationSeconds();
  public A withLeaseDurationSeconds(Integer leaseDurationSeconds);
  public Boolean hasLeaseDurationSeconds();
  public A addToManagedClusterClientConfigs(int index,ClientConfig item);
  public A setToManagedClusterClientConfigs(int index,ClientConfig item);
  public A addToManagedClusterClientConfigs(io.fabric8.openclustermanagement.api.model.cluster.v1.ClientConfig... items);
  public A addAllToManagedClusterClientConfigs(Collection<ClientConfig> items);
  public A removeFromManagedClusterClientConfigs(io.fabric8.openclustermanagement.api.model.cluster.v1.ClientConfig... items);
  public A removeAllFromManagedClusterClientConfigs(Collection<ClientConfig> items);
  public A removeMatchingFromManagedClusterClientConfigs(Predicate<ClientConfigBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildManagedClusterClientConfigs instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ClientConfig> getManagedClusterClientConfigs();
  public List<ClientConfig> buildManagedClusterClientConfigs();
  public ClientConfig buildManagedClusterClientConfig(int index);
  public ClientConfig buildFirstManagedClusterClientConfig();
  public ClientConfig buildLastManagedClusterClientConfig();
  public ClientConfig buildMatchingManagedClusterClientConfig(Predicate<ClientConfigBuilder> predicate);
  public Boolean hasMatchingManagedClusterClientConfig(Predicate<ClientConfigBuilder> predicate);
  public A withManagedClusterClientConfigs(List<ClientConfig> managedClusterClientConfigs);
  public A withManagedClusterClientConfigs(io.fabric8.openclustermanagement.api.model.cluster.v1.ClientConfig... managedClusterClientConfigs);
  public Boolean hasManagedClusterClientConfigs();
  public A addNewManagedClusterClientConfig(String caBundle,String url);
  public ManagedClusterSpecFluent.ManagedClusterClientConfigsNested<A> addNewManagedClusterClientConfig();
  public ManagedClusterSpecFluent.ManagedClusterClientConfigsNested<A> addNewManagedClusterClientConfigLike(ClientConfig item);
  public ManagedClusterSpecFluent.ManagedClusterClientConfigsNested<A> setNewManagedClusterClientConfigLike(int index,ClientConfig item);
  public ManagedClusterSpecFluent.ManagedClusterClientConfigsNested<A> editManagedClusterClientConfig(int index);
  public ManagedClusterSpecFluent.ManagedClusterClientConfigsNested<A> editFirstManagedClusterClientConfig();
  public ManagedClusterSpecFluent.ManagedClusterClientConfigsNested<A> editLastManagedClusterClientConfig();
  public ManagedClusterSpecFluent.ManagedClusterClientConfigsNested<A> editMatchingManagedClusterClientConfig(Predicate<ClientConfigBuilder> predicate);
  public A withHubAcceptsClient();
  public interface ManagedClusterClientConfigsNested<N> extends Nested<N>,ClientConfigFluent<ManagedClusterSpecFluent.ManagedClusterClientConfigsNested<N>>{
    public N and();
    public N endManagedClusterClientConfig();
    
  }
  
}
